summaryrefslogtreecommitdiff
path: root/config/routes/project.rb
diff options
context:
space:
mode:
authorGitLab Bot <gitlab-bot@gitlab.com>2019-12-24 09:07:44 +0000
committerGitLab Bot <gitlab-bot@gitlab.com>2019-12-24 09:07:44 +0000
commit6593f1f627938f22090dec5221476772d3ed581d (patch)
treeac5b9adf00f24f1d7cbc59c7d78f7c4fd06a0001 /config/routes/project.rb
parent2f369bd95866b7f623387ce2b6acf646df3d5222 (diff)
downloadgitlab-ce-6593f1f627938f22090dec5221476772d3ed581d.tar.gz
Add latest changes from gitlab-org/gitlab@master
Diffstat (limited to 'config/routes/project.rb')
-rw-r--r--config/routes/project.rb10
1 files changed, 9 insertions, 1 deletions
diff --git a/config/routes/project.rb b/config/routes/project.rb
index 0cc8e83de2c..ddd1693ef02 100644
--- a/config/routes/project.rb
+++ b/config/routes/project.rb
@@ -274,8 +274,9 @@ constraints(::Constraints::ProjectUrlConstrainer.new) do
end
end
# The wiki routing contains wildcard characters so
# its preferable to keep it below all other project routes
+ draw :repository_scoped
draw :wiki
end
# End of the /-/ scope.
@@ -481,6 +482,13 @@ constraints(::Constraints::ProjectUrlConstrainer.new) do
# its preferable to keep it below all other project routes
draw :repository
+ # To ensure an old unscoped routing is used for the UI we need to
+ # add prefix 'as' to the scope routing and place it below original routing.
+ # Issue https://gitlab.com/gitlab-org/gitlab/issues/118849
+ scope '-', as: 'scoped' do
+ draw :repository
+ end
+
# All new routes should go under /-/ scope.
# Look for scope '-' at the top of the file.
# rubocop: enable Cop/PutProjectRoutesUnderScope
@@ -274,8 +274,9 @@ constraints(::Constraints::ProjectUrlConstrainer.new) do
end
end
- # The wiki routing contains wildcard characters so
+ # The wiki and repository routing contains wildcard characters so
# its preferable to keep it below all other project routes